@@ -4,6 +4,7 @@
 import os
 import sys
 import esky
+import esky.util
 
 if sys.platform == "win32":
     dotexe = ".exe"
@@ -14,6 +15,7 @@ else:
 import eskytester
 eskytester.yes_i_am_working()
 eskytester.yes_my_deps_are_working()
+eskytester.yes_my_data_is_installed()
 
 #  Upgrade to the next version (0.2, even though 0.3 is available)
 assert sys.frozen
@@ -28,7 +30,7 @@ assert app.find_update() == "0.3"
 
 assert os.path.isfile(os.path.join(app.appdir,"script1"+dotexe))
 assert os.path.isfile(os.path.join(app.appdir,"script2"+dotexe))
-assert os.path.isdir(os.path.join(app.appdir,"eskytester-0.2"))
+assert os.path.isdir(os.path.join(app.appdir,"eskytester-0.2."+esky.util.get_platform()))
 script2 = os.path.join(app.appdir,"script2"+dotexe)
 os.execv(script2,[script2])
 
