@@ -12,10 +12,10 @@ from SimpleHTTPServer import SimpleHTTPRequestHandler
 from BaseHTTPServer import HTTPServer
 
 from distutils.core import setup as dist_setup
-from distutils.util import get_platform
 
 import esky
 from esky import bdist_esky
+from esky.util import extract_zipfile, get_platform
 
 
 def test_esky():
@@ -34,7 +34,10 @@ def test_esky():
             shutil.rmtree(deploydir)
         #  Build three increasing versions of the test package
         metadata = dict(name="eskytester",packages=["eskytester"],author="rfk",
-                        description="the esky test package",script_args=["bdist_esky"])
+                        description="the esky test package",
+                        data_files=[("data",["eskytester/datafile.txt"])],
+                        package_data={"eskytester":["pkgdata.txt"]},
+                        script_args=["bdist_esky"])
         dist_setup(version="0.1",scripts=["eskytester/script1.py"],**metadata)
         dist_setup(version="0.2",scripts=["eskytester/script1.py","eskytester/script2.py"],**metadata)
         dist_setup(version="0.3",scripts=["eskytester/script2.py","eskytester/script3.py"],**metadata)
@@ -43,21 +46,8 @@ def test_esky():
         threading.Thread(target=server.serve_forever).start()
         #  Set up the deployed esky environment for the initial version
         zfname = os.path.join("dist","eskytester-0.1.%s.zip"%(platform,))
-        zf = zipfile.ZipFile(zfname,"r")
         os.mkdir(deploydir)
-        for nm in zf.namelist():
-            outfilenm = os.path.join(deploydir,nm)
-            if not os.path.isdir(os.path.dirname(outfilenm)):
-                os.makedirs(os.path.dirname(outfilenm))
-            infile = zf.open(nm,"r")
-            outfile = open(outfilenm,"wb")
-            try:
-                shutil.copyfileobj(infile,outfile)
-            finally:
-                infile.close()
-                outfile.close()
-            mode = zf.getinfo(nm).external_attr >> 16L
-            os.chmod(outfilenm,mode)
+        extract_zipfile(zfname,deploydir)
         #  Run the first script, which will perform the necessary tests
         #  and write "tests-completed" file when done.
         if os.path.exists("tests-completed"):
@@ -78,16 +68,20 @@ def test_esky():
  
 def test_esky_locking():
     """Test that locking an Esky works correctly."""
+    platform = get_platform()
     appdir = tempfile.mkdtemp()
     try: 
-        os.mkdir(os.path.join(appdir,"testapp-0.1"))
-        open(os.path.join(appdir,"testapp-0.1","library.zip"),"wb").close()
+        vdir = os.path.join(appdir,"testapp-0.1.%s" % (platform,))
+        os.mkdir(vdir)
+        open(os.path.join(vdir,"library.zip"),"wb").close()
         e1 = esky.Esky(appdir,"http://example.com/downloads/")
         assert e1.name == "testapp"
         assert e1.version == "0.1"
+        assert e1.platform == platform
         e2 = esky.Esky(appdir,"http://example.com/downloads/")
         assert e2.name == "testapp"
         assert e2.version == "0.1"
+        assert e2.platform == platform
         locked = []; errors = [];
         trigger1 = threading.Event(); trigger2 = threading.Event()
         def runit(e,t1,t2):
